//
//  ViewController.m
//  SideMenuMap_ObjC
//
//  Created by Torrey Betts on 1/14/16.
//  Copyright (c) 2016 Torrey Betts. All rights reserved.
//


#import <MapKit/MapKit.h>
#import <IG/IG.h>
#import "ViewController.h"


@interface ViewController () <IGGridViewDelegate>
{
    IGSideMenuView *_sideMenu;
    UIBarButtonItem *_menuButton;
    IGGridView *_gridMenu;
    IGGridViewDataSourceHelper *_gridDSH;
    NSArray *_menuItems;
    IGGridViewDarkTheme *_darkTheme;
    MKMapView *_map;
    UITapGestureRecognizer *_mapTapGesture;
}
@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.title = @"Side Menu Sample";

    [self initSideMenu];
    [self initMap];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (BOOL)prefersStatusBarHidden
{
    return YES;
}

- (void)gridView:(IGGridView *)gridView didSelectRowAtPath:(IGRowPath *)path
{
    [self performSelector:@selector(deselectCell) withObject:nil afterDelay:0.75];
}

- (void)initSideMenu
{
    _sideMenu = [[IGSideMenuView alloc] initWithFrame:self.view.bounds];
    _sideMenu.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth;
    _sideMenu.presentsWithGesture = NO;
    [self.view addSubview:_sideMenu];

    _menuItems = @[@"Option 1", @"Option 2", @"Option 3", @"Option 4", @"Option 5", @"Option 6"];

    _gridMenu = [[IGGridView alloc] initWithFrame:CGRectMake(0, 0, 250, 1) style:IGGridViewStyleDefault];
    _gridMenu.headerHeight = 0;
    _gridMenu.rowHeight = 75;
    _gridMenu.emptyRows = NO;
    _gridMenu.backgroundColor = [UIColor colorWithWhite:0.15 alpha:1.0];
    _gridMenu.theme = _darkTheme = [[IGGridViewDarkTheme alloc] init];
    _gridMenu.delegate = self;

    _gridDSH = [[IGGridViewDataSourceHelper alloc] init];
    _gridDSH.data = _menuItems;

    _gridMenu.dataSource = _gridDSH;
    _sideMenu.rightMenuView = _gridMenu;

    _menuButton = [[UIBarButtonItem alloc] initWithTitle:@"☰" style:UIBarButtonItemStylePlain target:self action:@selector(toggleSideMenu)];
    self.navigationItem.rightBarButtonItems = @[_menuButton];
}

- (void)initMap
{
    _map = [[MKMapView alloc] initWithFrame:_sideMenu.contentView.bounds];
    _map.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth;
    [_sideMenu.contentView addSubview:_map];

    _mapTapGesture = [[UITapGestureRecognizer alloc] initWithTarget:self action:@selector(mapTapped:)];
    _mapTapGesture.numberOfTapsRequired = 1;
    _mapTapGesture.numberOfTouchesRequired = 1;
    [_map addGestureRecognizer:_mapTapGesture];
}

- (void)mapTapped:(UIGestureRecognizer *)recognizer
{
    if (recognizer.state != UIGestureRecognizerStateEnded)
        return;

    CGPoint touchPoint = [recognizer locationInView:_map];
    CLLocationCoordinate2D touchMapCoordinate = [_map convertPoint:touchPoint toCoordinateFromView:_map];

    MKPointAnnotation *pa = [[MKPointAnnotation alloc] init];
    pa.coordinate = touchMapCoordinate;
    pa.title = @"Location XYZ";
    [_map addAnnotation:pa];
}

- (void)toggleSideMenu
{
    if (_sideMenu.isMenuOpen)
        [_sideMenu closeSideMenu];
    else
        [_sideMenu openSideMenu:IGSideMenuLocationRight];
}

- (void)deselectCell
{
    [_sideMenu closeSideMenu];
    [_gridMenu deselectAll];
}

@end